[GRASS-SVN] r30732 - grass/trunk/lib/vector/diglib
svn_grass at osgeo.org
svn_grass at osgeo.org
Tue Mar 25 13:51:57 EDT 2008
Author: martinl
Date: 2008-03-25 13:51:56 -0400 (Tue, 25 Mar 2008)
New Revision: 30732
Modified:
grass/trunk/lib/vector/diglib/update.c
Log:
diglib: Doxygen strings updated for update.c
Modified: grass/trunk/lib/vector/diglib/update.c
===================================================================
--- grass/trunk/lib/vector/diglib/update.c 2008-03-25 17:35:39 UTC (rev 30731)
+++ grass/trunk/lib/vector/diglib/update.c 2008-03-25 17:51:56 UTC (rev 30732)
@@ -1,28 +1,39 @@
-/***************************************************************************
-*
-* MODULE: Vector library
-*
-* AUTHOR(S): Radim Blazek
-*
-* PURPOSE: Lower level functions for reading/writing/manipulating vectors.
-*
-* COPYRIGHT: (C) 2001 by the GRASS Development Team
-*
-* This program is free software under the GNU General Public
-* License (>=v2). Read the file COPYING that comes with GRASS
-* for details.
-*
-*****************************************************************************/
+/**
+ * \file update.c
+ *
+ * \brief Vector library - update topology (lower level functions)
+ *
+ * Lower level functions for reading/writing/manipulating vectors.
+ *
+ * (C) 2001 by the GRASS Development Team
+ *
+ * This program is free software under the GNU General Public License
+ * (>=v2). Read the file COPYING that comes with GRASS for details.
+ *
+ * \author Radim Blazek
+ */
+
#include <stdlib.h>
#include <grass/gis.h>
#include <grass/Vect.h>
+/*!
+ \brief Reset number of updated lines
+
+ \param Plus pointer to Plus_head structure
+*/
void
dig_line_reset_updated ( struct Plus_head *Plus )
{
Plus->n_uplines = 0;
}
+/*!
+ \brief Add new line to updated
+
+ \param Plus pointer to Plus_head structure
+ \param line line id
+*/
void
dig_line_add_updated ( struct Plus_head *Plus, int line )
{
@@ -44,12 +55,23 @@
Plus->n_uplines++;
}
+/*!
+ \brief Reset number of updated nodes
+
+ \param Plus pointer to Plus_head structure
+*/
void
dig_node_reset_updated ( struct Plus_head *Plus )
{
Plus->n_upnodes = 0;
}
+/*!
+ \brief Add node to updated
+
+ \param Plus pointer to Plus_head structure
+ \param node node id
+*/
void
dig_node_add_updated ( struct Plus_head *Plus, int node )
{
@@ -70,4 +92,3 @@
Plus->upnodes[Plus->n_upnodes] = node;
Plus->n_upnodes++;
}
-
More information about the grass-commit
mailing list